// Copyright 2023 The Inspektor Gadget authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//go:build linux

package oci

import (
	"os"
	"syscall"
)

func copyFileOwner(modelFile string, targetFiles ...string) error {
	info, err := os.Stat(modelFile)
	if err != nil {
		return err
	}

	stat, ok := info.Sys().(*syscall.Stat_t)
	if !ok {
		return nil
	}

	for _, targetFile := range targetFiles {
		if targetFile == "" {
			continue
		}
		err := os.Chown(targetFile, int(stat.Uid), int(stat.Gid))
		if err != nil {
			return err
		}
	}

	return nil
}
